/*
 * Copyright (C) 2022 European Spallation Source ERIC.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.openepics.names.util;

/**
 * Utility class to assist in handling of text.
 *
 * @author Lars Johansson
 */
public class TextUtil {

    // application

    public static final String NAMING                          = "Naming";

    // field
    //     name, structure
    //         name also field

    public static final String NAME                            = "name";
    public static final String STRUCTURE                       = "structure";
    public static final String SYSTEMGROUP                     = "system group";
    public static final String SYSTEM                          = "system";
    public static final String SUBSYSTEM                       = "subsystem";
    public static final String DISCIPLINE                      = "discipline";
    public static final String DEVICEGROUP                     = "device group";
    public static final String DEVICETYPE                      = "device type";

    public static final String COMMENT                         = "comment";
    public static final String DESCRIPTION                     = "description";
    public static final String INDEX                           = "index";
    public static final String MNEMONIC                        = "mnemonic";
    public static final String MNEMONICPATH                    = "mnemonicpath";
    public static final String PARENT                          = "parent";
    public static final String PARENTDEVICESTRUCTURE           = "parentdevicestructure";
    public static final String PARENTSYSTEMSTRUCTURE           = "parentsystemstructure";
    public static final String STATUS                          = "status";
    public static final String TYPE                            = "type";
    public static final String UUID                            = "uuid";

    public static final String CONVENTION_NAME                 = "convention name";
    public static final String CONVENTION_NAME_EQUIVALENCE     = "convention name equivalence";
    public static final String MNEMONIC_PATH                   = "mnemonic path";
    public static final String MNEMONIC_PATH_EQUIVALENCE       = "mnemonic path equivalence";
    public static final String SYSTEM_STRUCTURE                = "system structure";

    // common

    public static final String SPACE                           = " ";

    // validation

    public static final String EXISTS                          = "exists";
    public static final String HAS_DUPLICATE                   = "has duplicate";
    public static final String IS_NOT_AVAILABLE                = "is not available";
    public static final String IS_NOT_CORRECT                  = "is not correct";
    public static final String IS_NOT_VALID                    = "is not valid";

    public static final String DATA_IS_DELETED                 = "data is deleted";
    public static final String DATA_IS_NOT_AVAILABLE           = "data is not available";
    public static final String DATA_IS_NOT_CORRECT             = "data is not correct";
    public static final String DATA_IS_NOT_VALID               = "data is not valid";

    public static final String VALUE_IS_NOT_AVAILABLE          = "value is not available";
    public static final String VALUE_IS_NOT_CORRECT            = "value is not correct";
    public static final String VALUE_IS_NOT_EMPTY              = "value is not empty";
    public static final String VALUE_IS_NOT_VALID              = "value is not valid";
    public static final String VALUES_ARE_NOT_CORRECT          = "values are not correct";

    // validation message

    public static final String CONVENTION_NAME_EXISTS                  = CONVENTION_NAME             + SPACE + EXISTS;
    public static final String CONVENTION_NAME_EQUIVALENCE_EXISTS      = CONVENTION_NAME_EQUIVALENCE + SPACE + EXISTS;
    public static final String CONVENTION_NAME_IS_NOT_CORRECT          = CONVENTION_NAME             + SPACE + IS_NOT_CORRECT;

    public static final String MNEMONIC_PATH_HAS_DUPLICATE             = MNEMONIC_PATH               + SPACE + HAS_DUPLICATE;
    public static final String MNEMONIC_PATH_IS_NOT_AVAILABLE          = MNEMONIC_PATH               + SPACE + IS_NOT_AVAILABLE;
    public static final String MNEMONIC_PATH_IS_NOT_VALID              = MNEMONIC_PATH               + SPACE + IS_NOT_VALID;
    public static final String MNEMONIC_PATH_EQUIVALENCE_HAS_DUPLICATE = MNEMONIC_PATH_EQUIVALENCE   + SPACE + HAS_DUPLICATE;
    public static final String STRUCTURE_MNEMONIC_PATH_IS_NOT_VALID    = STRUCTURE                   + SPACE + MNEMONIC_PATH_IS_NOT_VALID;

    public static final String DEVICETYPE_OR_INDEX_IS_NOT_AVAILABLE    = "device type or index is not available";
    public static final String ONE_OR_MORE_ELEMENTS_ARE_NOT_CORRECT    = "one or more elements are not correct";
    public static final String OPERATION_COULD_NOT_BE_PERFORMED        = "operation could not be performed";

    public static final String PARENT_IS_NOT_AVAILABLE                 = PARENT           + SPACE + IS_NOT_AVAILABLE;
    public static final String SYSTEMGROUP_IS_NOT_AVAILABLE            = SYSTEMGROUP      + SPACE + IS_NOT_AVAILABLE;
    public static final String SYSTEM_IS_NOT_AVAILABLE                 = SYSTEM           + SPACE + IS_NOT_AVAILABLE;
    public static final String SUBSYSTEM_IS_NOT_AVAILABLE              = SUBSYSTEM        + SPACE + IS_NOT_AVAILABLE;
    public static final String DISCIPLINE_IS_NOT_AVAILABLE             = DISCIPLINE       + SPACE + IS_NOT_AVAILABLE;
    public static final String DEVICEGROUP_IS_NOT_AVAILABLE            = DEVICEGROUP      + SPACE + IS_NOT_AVAILABLE;
    public static final String DEVICETYPE_IS_NOT_AVAILABLE             = DEVICETYPE       + SPACE + IS_NOT_AVAILABLE;

    public static final String PARENT_IS_NOT_CORRECT                   = PARENT           + SPACE + IS_NOT_CORRECT;
    public static final String SYSTEM_STRUCTURE_IS_NOT_CORRECT         = SYSTEM_STRUCTURE + SPACE + IS_NOT_CORRECT;
    public static final String SYSTEMGROUP_IS_NOT_CORRECT              = SYSTEMGROUP      + SPACE + IS_NOT_CORRECT;
    public static final String SYSTEM_IS_NOT_CORRECT                   = SYSTEM           + SPACE + IS_NOT_CORRECT;
    public static final String SUBSYSTEM_IS_NOT_CORRECT                = SUBSYSTEM        + SPACE + IS_NOT_CORRECT;
    public static final String DISCIPLINE_IS_NOT_CORRECT               = DISCIPLINE       + SPACE + IS_NOT_CORRECT;
    public static final String DEVICEGROUP_IS_NOT_CORRECT              = DEVICEGROUP      + SPACE + IS_NOT_CORRECT;
    public static final String DEVICETYPE_IS_NOT_CORRECT               = DEVICETYPE       + SPACE + IS_NOT_CORRECT;

    public static final String DISCIPLINE_IS_NOT_VALID                 = DISCIPLINE       + SPACE + IS_NOT_VALID;
    public static final String DEVICEGROUP_IS_NOT_VALID                = DEVICEGROUP      + SPACE + IS_NOT_VALID;
    public static final String INDEX_IS_NOT_VALID                      = INDEX            + SPACE + IS_NOT_VALID;
    public static final String MNEMONIC_IS_NOT_VALID                   = MNEMONIC         + SPACE + IS_NOT_VALID;

    public static final String FILE_COULD_NOT_BE_PARSED                = "File could not be parsed";

    // TODO check if necessary when authentication authorization is introduced
    public static final String TEST_WHO                                = "test who";

    /**
     * This class is not to be instantiated.
     */
    private TextUtil() {
        throw new IllegalStateException("Utility class");
    }

}
